@@ -1,18 +1,14 @@
-# Copyright (c) 2002-2013 LOGILAB S.A. (Paris, FRANCE).
-# http://www.logilab.fr/ -- mailto:contact@logilab.fr
-#
-# This program is free software; you can redistribute it and/or modify it under
-# the terms of the GNU General Public License as published by the Free Software
-# Foundation; either version 2 of the License, or (at your option) any later
-# version.
-#
-# This program is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along with
-# this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+# Copyright (c) 2006, 2008, 2010, 2013-2014 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
+# Copyright (c) 2014 Brett Cannon <brett@python.org>
+# Copyright (c) 2014 Arun Persaud <arun@nubati.net>
+# Copyright (c) 2015-2017 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2015 Ionel Cristian Maries <contact@ionelmc.ro>
+# Copyright (c) 2017 hippo91 <guillaume.peillex@gmail.com>
+# Copyright (c) 2018 ssolanki <sushobhitsolanki@gmail.com>
+
+# Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
+# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+
 """
 generic classes/functions for pyreverse core/extensions
 """
@@ -25,22 +21,24 @@ import sys
 ########### pyreverse option utils ##############################
 
 
-RCFILE = '.pyreverserc'
+RCFILE = ".pyreverserc"
+
 
 def get_default_options():
     """
     Read config file and return list of options
     """
     options = []
-    home = os.environ.get('HOME', '')
+    home = os.environ.get("HOME", "")
     if home:
         rcfile = os.path.join(home, RCFILE)
         try:
             options = open(rcfile).read().split()
         except IOError:
-            pass # ignore if no config file found
+            pass  # ignore if no config file found
     return options
 
+
 def insert_default_options():
     """insert default options to sys.argv
     """
@@ -50,29 +48,31 @@ def insert_default_options():
         sys.argv.insert(1, arg)
 
 
-
 # astroid utilities ###########################################################
 
-SPECIAL = re.compile('^__[A-Za-z0-9]+[A-Za-z0-9_]*__$')
-PRIVATE = re.compile('^__[_A-Za-z0-9]*[A-Za-z0-9]+_?$')
-PROTECTED = re.compile('^_[_A-Za-z0-9]*$')
+SPECIAL = re.compile("^__[A-Za-z0-9]+[A-Za-z0-9_]*__$")
+PRIVATE = re.compile("^__[_A-Za-z0-9]*[A-Za-z0-9]+_?$")
+PROTECTED = re.compile("^_[_A-Za-z0-9]*$")
+
 
 def get_visibility(name):
     """return the visibility from a name: public, protected, private or special
     """
     if SPECIAL.match(name):
-        visibility = 'special'
+        visibility = "special"
     elif PRIVATE.match(name):
-        visibility = 'private'
+        visibility = "private"
     elif PROTECTED.match(name):
-        visibility = 'protected'
+        visibility = "protected"
 
     else:
-        visibility = 'public'
+        visibility = "public"
     return visibility
 
-ABSTRACT = re.compile('^.*Abstract.*')
-FINAL = re.compile('^[A-Z_]*$')
+
+ABSTRACT = re.compile("^.*Abstract.*")
+FINAL = re.compile("^[A-Z_]*$")
+
 
 def is_abstract(node):
     """return true if the given class node correspond to an abstract class
@@ -80,19 +80,22 @@ def is_abstract(node):
     """
     return ABSTRACT.match(node.name)
 
+
 def is_final(node):
     """return true if the given class/function node correspond to final
     definition
     """
     return FINAL.match(node.name)
 
+
 def is_interface(node):
     # bw compat
-    return node.type == 'interface'
+    return node.type == "interface"
+
 
 def is_exception(node):
     # bw compat
-    return node.type == 'exception'
+    return node.type == "exception"
 
 
 # Helpers #####################################################################
@@ -102,37 +105,41 @@ _SPECIAL = 2
 _PROTECTED = 4
 _PRIVATE = 8
 MODES = {
-    'ALL'       : 0,
-    'PUB_ONLY'  : _SPECIAL + _PROTECTED + _PRIVATE,
-    'SPECIAL'   : _SPECIAL,
-    'OTHER'     : _PROTECTED + _PRIVATE,
+    "ALL": 0,
+    "PUB_ONLY": _SPECIAL + _PROTECTED + _PRIVATE,
+    "SPECIAL": _SPECIAL,
+    "OTHER": _PROTECTED + _PRIVATE,
+}
+VIS_MOD = {
+    "special": _SPECIAL,
+    "protected": _PROTECTED,
+    "private": _PRIVATE,
+    "public": 0,
 }
-VIS_MOD = {'special': _SPECIAL, 'protected': _PROTECTED,
-           'private': _PRIVATE, 'public': 0}
 
 
-class FilterMixIn(object):
+class FilterMixIn:
     """filter nodes according to a mode and nodes' visibility
     """
+
     def __init__(self, mode):
         "init filter modes"
         __mode = 0
-        for nummod in mode.split('+'):
+        for nummod in mode.split("+"):
             try:
                 __mode += MODES[nummod]
             except KeyError as ex:
-                print('Unknown filter mode %s' % ex, file=sys.stderr)
+                print("Unknown filter mode %s" % ex, file=sys.stderr)
         self.__mode = __mode
 
-
     def show_attr(self, node):
         """return true if the node should be treated
         """
-        visibility = get_visibility(getattr(node, 'name', node))
+        visibility = get_visibility(getattr(node, "name", node))
         return not self.__mode & VIS_MOD[visibility]
 
 
-class ASTWalker(object):
+class ASTWalker:
     """a walker visiting a tree in preorder, calling on the handler:
 
     * visit_<class name> on entering a node, where class name is the class of
@@ -167,10 +174,12 @@ class ASTWalker(object):
         if methods is None:
             handler = self.handler
             kid = klass.__name__.lower()
-            e_method = getattr(handler, 'visit_%s' % kid,
-                               getattr(handler, 'visit_default', None))
-            l_method = getattr(handler, 'leave_%s' % kid,
-                               getattr(handler, 'leave_default', None))
+            e_method = getattr(
+                handler, "visit_%s" % kid, getattr(handler, "visit_default", None)
+            )
+            l_method = getattr(
+                handler, "leave_%s" % kid, getattr(handler, "leave_default", None)
+            )
             self._cache[klass] = (e_method, l_method)
         else:
             e_method, l_method = methods
@@ -191,6 +200,7 @@ class ASTWalker(object):
 
 class LocalsVisitor(ASTWalker):
     """visit a project by traversing the locals dictionary"""
+
     def __init__(self):
         ASTWalker.__init__(self, self)
         self._visited = {}
@@ -198,13 +208,14 @@ class LocalsVisitor(ASTWalker):
     def visit(self, node):
         """launch the visit starting from the given node"""
         if node in self._visited:
-            return
-        self._visited[node] = 1 # FIXME: use set ?
+            return None
+        self._visited[node] = 1  # FIXME: use set ?
         methods = self.get_callbacks(node)
         if methods[0] is not None:
             methods[0](node)
-        if hasattr(node, 'locals'): # skip Instance and other proxy
+        if hasattr(node, "locals"):  # skip Instance and other proxy
             for local_node in node.values():
                 self.visit(local_node)
         if methods[1] is not None:
             return methods[1](node)
+        return None
